#ifndef BOOST_SIMD_INCLUDE_FUNCTIONS_CONJ_HPP_INCLUDED
#define BOOST_SIMD_INCLUDE_FUNCTIONS_CONJ_HPP_INCLUDED

#include <boost/simd/arithmetic/include/functions/conj.hpp>

#endif
